@@ -13,21 +13,34 @@ int main(int argc, char *argv[])
     QCoreApplication::setApplicationName("TPlayer");
     QCoreApplication::setApplicationVersion("0.0.2beta");
 
-
+QString langPath;
 #ifdef Q_WS_MAEMO_5
 base_path="/home/user/";
+langPath = "/opt/tplayer/lang/";
 #else
 #ifdef Q_OS_WIN32
 base_path=qApp->applicationDirPath()+"/";
+langPath = base_path+"/lang/";
 #else
 #ifdef Q_WS_S60
 base_path="/data/tplayer/";
+langPath = base_path+"/lang/";
 #else
 base_path="/usr/share/tplayer/";
+langPath = base_path+"/lang/";
 #endif
 #endif
 #endif
 
+QString lang = QLocale::languageToString(QLocale::system().language()).toLower().trimmed();
+qDebug(QString("Starting TPlayer with %1 locale").arg(lang).toAscii());
+
+//if (QFile::exists(langPath + lang + ".qm"))
+//{
+QTranslator translator;
+translator.load(langPath + lang + ".qm");
+app.installTranslator(&translator);
+//}
 
 db = QSqlDatabase::addDatabase("QSQLITE");
 db.setDatabaseName(base_path+"tplayer-list");
