@@ -89,8 +89,43 @@ void MainWindow::dbus(QString what,QString how){
 
 #endif
 
+void MainWindow::m3uForDir(){
+    QString path=QFileDialog::getExistingDirectory(this,tr("Select directory"),"/home/user/MyDocs");
+    if (path.isEmpty())return;
+
+    QString spath=QFileDialog::getSaveFileName(this,tr("Save m3u as"),"/home/user/MyDocs","m3u(*.m3u)",new QString("m3u(*.m3u)"));
+    if (spath.isEmpty())return;
+
+    QFile fl(spath);
+    if (!fl.open(QFile::Text|QFile::WriteOnly)){
+        QMessageBox dt;
+        dt.setText(tr("Access error while trying to open file %1").arg(spath));
+        dt.exec();
+        return;
+    }
+
+    QTextStream out(&fl);
+     out << "#EXTM3U\n";
+
+    QDir dr(path);
+    dr.setNameFilters(namefilter);
+    QDirIterator it(dr, QDirIterator::Subdirectories);
+    int yt=0;
+    while (it.hasNext()) {
+        it.next();
+        out<<QString("#EXTINF:0, %1\n").arg(it.fileName());
+        out<<it.filePath()<<"\n";
+        yt++;
+    }
+    fl.close();
+
+    QMessageBox dt2;
+    dt2.setText(tr("Playlist created,files count:%1").arg(yt));
+    dt2.exec();
+}
 
 void MainWindow::inet(QListWidgetItem* item){
+    set_setting("source_list","1");
 inet_source=1;
 
 
@@ -102,19 +137,26 @@ inet_source=1;
 }
 
 void MainWindow::load_inet(){
-
-QFile file(base_path+"tplayer-inet.m3u");
-        if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
-            return;
+QString lst=get_setting("list_path");
+if (lst.isEmpty())lst=base_path+"tplayer-inet.m3u";
 
 
+QFile file(lst);
+if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
+    QMessageBox td;
+    td.setText(tr("Error while loading %1 playlist").arg(lst));
+    td.exec();
+    return;}
+
+ui.listWidget_2->clear();
+ilist.clear();
 
 QTextStream in(&file);
 
 
      QString line = in.readLine();
 
-      if (line!="#EXTM3U")return;
+      if (line!="#EXTM3U")return; // here i should create .pls\.cue file support
 
 int t=0;
         while (!in.atEnd()) {
@@ -126,7 +168,7 @@ int t=0;
            rx.indexIn(line);
            QString title=rx.cap(1);
            line = in.readLine();
-           ilist.insert(t++,QStringList()<<line<<title<<"Internet radio");
+           ilist.insert(t++,QStringList()<<line<<title<<tr("Internet radio"));
 
               ui.listWidget_2->addItem(title);
         }
@@ -183,7 +225,7 @@ for (int i = 0; i < 10; ++i)
     lt->addLayout(tmpLay);
     sliders.append(s);
 }
-QCheckBox *enabled = new QCheckBox("Enable equalizer");
+QCheckBox *enabled = new QCheckBox(tr("Enable equalizer"));
 if (get_setting("eq_state")=="1")enabled->setChecked(true); else enabled->setChecked(false);
 toggleEqualizer(enabled->isChecked());
 connect(enabled, SIGNAL(toggled(bool)), this, SLOT(toggleEqualizer(bool)));
@@ -191,7 +233,7 @@ connect(enabled, SIGNAL(toggled(bool)), this, SLOT(toggleEqualizer(bool)));
 
 vb->addWidget(enabled);
 vb->addLayout(lt);
-QPushButton *reset = new QPushButton("Functions");
+QPushButton *reset = new QPushButton(tr("Functions"));
 
 eq_menu=new QMenu;
 load_eqs();
@@ -234,6 +276,7 @@ connect(ui.listWidget_2,SIGNAL(itemDoubleClicked(QListWidgetItem*)),this,SLOT(in
 
 connect(ui.pushButton_23,SIGNAL(clicked()),this,SLOT(i_fn_click()));
 connect (ui.pushButton_22,SIGNAL(clicked()),this,SLOT(inform()));
+connect (ui.pushButton_24,SIGNAL(clicked()),this,SLOT(m3uForDir()));
 //
 
 load_inet();
@@ -259,12 +302,13 @@ connect (opt,SIGNAL(accepted()),this,SLOT(load()));
           connect(moo,SIGNAL(stateChanged(Phonon::State,Phonon::State)),this,SLOT(changePlay(Phonon::State,Phonon::State)));
           connect(ui.listWidget,SIGNAL(itemDoubleClicked(QListWidgetItem*)),this,SLOT(currentItemChanged(QListWidgetItem*)));
           connect(moo,SIGNAL(finished()),this,SLOT(next()));
-
+connect(qApp,SIGNAL(focusChanged(QWidget*,QWidget*)),this,SLOT(repaint()));
+connect(device,SIGNAL(volumeChanged(qreal)),this,SLOT(volumeChanged(qreal)));
 click1();
 
 
 
-
+inet_source=get_setting("source_list").toLong();
 
 reload();
 int row=-1;
@@ -279,12 +323,29 @@ if (!rw.trimmed().isEmpty()){
 
 ui.listWidget->setCurrentRow(row);
 
-inet_source=0;
+
+
+
+
+int row2=-1;
+rw=get_setting("last_played_l");
+if (!rw.trimmed().isEmpty()){
+    QMapIterator<int,QStringList> idk2(ilist);
+    while(idk2.hasNext()&&row2==-1){
+        idk2.next();
+        if (idk2.value().at(0)==rw)row2=idk2.key();
+        }
+}
+ui.listWidget_2->setCurrentRow(row2);
+
+
+if (inet_source==0){
 if (row!=-1)
  moo->setCurrentSource(list.value(ui.listWidget->currentRow()).at(0));
-
-
-
+}else{
+if (row2!=-1)
+ moo->setCurrentSource(ilist.value(ui.listWidget_2->currentRow()).at(0));
+}
 
 
 #ifdef Q_WS_MAEMO_5
@@ -321,10 +382,10 @@ load_eq(eq_name);
 
 void MainWindow::load_eqs(){
     eq_menu->clear();
-    QMenu *fn=new QMenu("Equalizer",eq_menu);
-     fn->addAction("Save to new",this,SLOT(save_eq_d()));
-     fn->addAction("Save current",this,SLOT(save_eq()));
-     fn->addAction("Remove current",this,SLOT(rem_eq()));
+    QMenu *fn=new QMenu(tr("Equalizer"),eq_menu);
+     fn->addAction(tr("Save to new"),this,SLOT(save_eq_d()));
+     fn->addAction(tr("Save current"),this,SLOT(save_eq()));
+     fn->addAction(tr("Remove current"),this,SLOT(rem_eq()));
 eq_menu->addMenu(fn);
 
     QString sql="SELECT `name` FROM `equalizer` WHERE 1";
@@ -339,7 +400,6 @@ eq_menu->addMenu(fn);
 }
 
 void MainWindow::eq_fn_click(){
-    // just a wraper
     eq_menu->exec(QCursor::pos());
 }
 
@@ -364,9 +424,9 @@ void MainWindow::load_eq(QString name){
 void MainWindow::save_eq_d(){
     QDialog *d=new QDialog();
     QVBoxLayout *h=new QVBoxLayout(d);
-    QLabel *y=new QLabel("<center>New equalizer name</center>",d);
+    QLabel *y=new QLabel(tr("<center>New equalizer name</center>"),d);
     QLineEdit *u=new QLineEdit(d);
-    QPushButton *ok=new QPushButton("Create equalizer",d);
+    QPushButton *ok=new QPushButton(tr("Create equalizer"),d);
     h->addWidget(y);
     h->addWidget(u);
     h->addWidget(ok);
@@ -498,46 +558,40 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *event)
 
         default:
             return QObject::eventFilter(obj, event); break;
-
-
-
         }
-
     } else {
-        // standard event processing
         return QObject::eventFilter(obj, event);
     }
 }
 
-void MainWindow::keyPressEvent(QKeyEvent* event)
-  {
 
-      switch (event->key()) {
+void MainWindow::keyPressEvent(QKeyEvent* event){
+switch (event->key()) {
       case Qt::Key_F7:
-device->setVolume(device->volume()+0.1);
-        event->accept();
-          break;
-
-
-      case Qt::Key_F8:
-         device->setVolume(device->volume()-0.1);
+    if (device->volume()+vol_change<=1)
+          device->setVolume(device->volume()+vol_change);
+    else
+        device->setVolume(1);
           event->accept();
           break;
+      case Qt::Key_F8:
+          if (device->volume()-vol_change>=0)
+          device->setVolume(device->volume()-vol_change);
+          else
+              device->setVolume(0);
 
-     }
-
-
-
-
-
-      QWidget::keyPressEvent(event);
-  }
-
+          event->accept();
+          break;
+      default:
+          QWidget::keyPressEvent(event);
+          break;
+}
+}
 
 
 void MainWindow::inform(){
 QDialog dg;
-QString text="Filename : "+moo->currentSource().fileName()+"<br />";
+QString text=tr("Filename : %1 <br />").arg(moo->currentSource().fileName());
  QMap<QString, QString> metaData = moo->metaData();
  QMapIterator<QString, QString> inf(metaData);
  while(inf.hasNext()){
@@ -551,16 +605,12 @@ QScrollArea tu(&dg);
  QLabel t(QString(text),&tu);
 tu.setWidget(&t);
 
-// fg->addWidget(&t);
-// t.setTextInteractionFlags(Qt::TextBrowserInteraction|Qt::TextSelectableByMouse);
-
 dg.exec();
 }
 
 
 
 void MainWindow::sliderChanged (int val){
-
     QSlider* s = qobject_cast<QSlider*>(sender ());
     if (s)
     {
@@ -577,7 +627,7 @@ void MainWindow::sliderChanged (int val){
 void MainWindow::resetAll (){
        foreach (QSlider* s, sliders)
        {
-s->setValue(0);
+       s->setValue(0);
        }
 }
 
@@ -591,15 +641,15 @@ void MainWindow::toggleEqualizer(bool val)
        audioPath.removeEffect (eqEffect);
        set_setting ("eq_state","0");
    }
-
-
-
 }
 
 
 
 
 
+void MainWindow::volumeChanged ( qreal newVolume ){
+    set_setting("last_volume",QString("%1").arg(newVolume*100));
+}
 
 void MainWindow::load(){
     rotate=get_setting("rotate").toLong();
@@ -637,46 +687,45 @@ double freq=get_setting("FMTX-freq").toDouble();
 if (freq<88)freq=88.1;
 ui.doubleSpinBox->setValue(freq);
 
+int vol;
+switch (get_setting("volume_behaviour").toLong()){
+case 0:
+    vol=100;
+    break;
+case 1:
+ vol=get_setting("last_volume").toLong();
+ break;
+case 2:
+ vol=0;
+ break;
+}
+device->setVolume((qreal)vol/100);
+
+size=get_setting("volume_change").toLong();
+if (size==0)size=10;
+vol_change=(qreal)(size)/100;
+
 #ifdef Q_WS_MAEMO_5
  if (rotate==2){
  this-> setAttribute(Qt::WA_Maemo5AutoOrientation, true);
  }else if(rotate==1){
       setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
-  }else{
+ }else{
        setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
-  }
-  connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
-orientationChanged();
+ }
 #endif
 }
 
-void MainWindow::orientationChanged()
-{
-/*
-    QRect screenGeometry = QApplication::desktop()->screenGeometry();
-    if (screenGeometry.width() > screenGeometry.height())
-    {
-        //land
-        QHBoxLayout *y=new QHBoxLayout(ui.widget);
-        y->addWidget(ui.frame_3);
-        y->addWidget(ui.frame);
-    }else{
-     // port
-        QHBoxLayout *y=new QHBoxLayout(ui.widget);
-        y->addWidget(ui.frame_3);
-        y->addWidget(ui.frame);
-    }*/
 
-}
 
 void MainWindow::about(){
     QDialog *dwidget=new QDialog(0);
-    QLabel *text=new QLabel("<center><h3>TPlayer</h3></center><br />This program is distributed under terms of GNU GPL v3<br />" \
+    QLabel *text=new QLabel(tr("<center><h3>TPlayer</h3></center><br />This program is distributed under terms of GNU GPL v3<br />" \
                             "Source code can be founded at <a href=\"http://googlecode.com/p/tplayer\">http://googlecode.com/p/tplayer</a><br /><br />" \
                             "Lead developer: <bold>Bonapart</bold><br />" \
-                            "Web-developer : <bold>[vs]</bold>",dwidget);
-    QPushButton *aqt=new QPushButton("About Qt",dwidget);
-    QPushButton *kbd=new QPushButton("Keyboard help",dwidget);
+                            "Web-developer : <bold>[vs]</bold>","you can insert translator info here"),dwidget);
+    QPushButton *aqt=new QPushButton(tr("About Qt"),dwidget);
+    QPushButton *kbd=new QPushButton(tr("Keyboard help"),dwidget);
     QVBoxLayout *mlay=new QVBoxLayout(dwidget);
     QHBoxLayout *dlay=new QHBoxLayout();
     connect(aqt,SIGNAL(clicked()),qApp,SLOT(aboutQt()));
@@ -692,7 +741,7 @@ dwidget->exec();
 }
 void MainWindow::kbdhelp(){
     QDialog *dg=new QDialog(0);
-    QString text= QString("left key - previous song<br />" \
+    QString text= QString(tr("left key - previous song<br />" \
                           "right key - next song<br />" \
                           "space key - play\\pause<br />" \
                           "m key - mute\\unmute<br />" \
@@ -702,17 +751,16 @@ void MainWindow::kbdhelp(){
                           "v - biography tab<br />" \
                           "b - equalizer tab<br />" \
                           "h - this message<br />" \
-                          "ctrl+q - quit");
+                          "ctrl+q - quit"));
 
 
     QScrollArea tu(dg);
-     QHBoxLayout *fg=new QHBoxLayout(dg);
-     fg->addWidget(&tu);
+    QHBoxLayout *fg=new QHBoxLayout(dg);
+    fg->addWidget(&tu);
 
-     QLabel t(QString(text),&tu);
+    QLabel t(QString(text),&tu);
     tu.setWidget(&t);
 
-
 dg->exec();
 }
 
@@ -818,7 +866,6 @@ QString genre = metaData.value("GENRE");
 if (genre=="")
     genre="Unknown";
 
-//list.insert(list.count(),QStringList()<< metaInformationResolver->currentSource().fileName()<<title<<artist<<genre<<album<<year);
 QSqlQuery query(db);
 QString sq="INSERT INTO tracks (path, title, artist, genre, album, year) "
            "VALUES ("
@@ -831,9 +878,6 @@ QString sq="INSERT INTO tracks (path, title, artist, genre, album, year) "
 
 query.exec(sq);
 
-
-
-
 queue.removeAt(queue.indexOf(metaInformationResolver->currentSource().fileName()));
 if (queue.count() > 0){
     ld->setWindowTitle(queue.first());
@@ -846,8 +890,6 @@ else{
     }
 
 }catch(int e){
-    qDebug(QString("Some error with code : %1").arg(e).toAscii());
-
 }
 }
 
@@ -863,7 +905,7 @@ void MainWindow::clear(){
 
 
 void MainWindow::next(){
-    if (inet_source!=1){
+if (inet_source!=1){
     if ((float)moo->currentTime()/(float)moo->totalTime()>0.5)
         scrobler->addTrack(list.value(ui.listWidget->currentRow()),moo->totalTime());
 
@@ -876,9 +918,20 @@ if (ui.listWidget->count()==0)return;
      moo->setCurrentSource(list.value(ui.listWidget->currentRow()).at(0));
     moo->play();
 }else{
-    QMessageBox g;
-    g.setText("Not allowed for intrnet streams");
-    g.exec();
+
+
+    if ((float)moo->currentTime()/(float)moo->totalTime()>0.5)
+        scrobler->addTrack(ilist.value(ui.listWidget_2->currentRow()),moo->totalTime());
+
+if (ui.listWidget_2->count()==0)return;
+    if (ui.listWidget_2->currentRow()<ui.listWidget_2->count()-1)
+    ui.listWidget_2->setCurrentRow(ui.listWidget_2->currentRow()+1);
+    else
+        ui.listWidget_2->setCurrentRow(0);
+
+     moo->setCurrentSource(ilist.value(ui.listWidget_2->currentRow()).at(0));
+    moo->play();
+
 }
 
 }
@@ -897,9 +950,20 @@ if (ui.listWidget->count()==0)return;
     moo->setCurrentSource(list.value(ui.listWidget->currentRow()).at(0));
     moo->play();
 }else{
-    QMessageBox g;
-    g.setText("Not allowed for intrnet streams");
-    g.exec();
+
+
+    if ((float)moo->currentTime()/(float)moo->totalTime()>0.5)
+        scrobler->addTrack(ilist.value(ui.listWidget_2->currentRow()),moo->totalTime());
+
+if (ui.listWidget_2->count()==0)return;
+    if (ui.listWidget_2->currentRow()>0)
+    ui.listWidget_2->setCurrentRow(ui.listWidget_2->currentRow()-1);
+    else
+        ui.listWidget_2->setCurrentRow(ui.listWidget_2->count()-1);
+
+     moo->setCurrentSource(ilist.value(ui.listWidget_2->currentRow()).at(0));
+    moo->play();
+
 }
 
 }
@@ -911,6 +975,7 @@ void MainWindow::play_pause(){
 }
 
 void MainWindow::currentItemChanged ( QListWidgetItem * current ){
+    set_setting("source_list","0");
     if (inet_source==0){
        emit track_change(list.value(ui.listWidget->row(current)).at(0));
     if (moo->currentTime()/moo->totalTime()>0.5)
@@ -943,7 +1008,7 @@ scrobler->now(list.value(ui.listWidget->currentRow()),moo->totalTime());
 #ifdef Q_WS_MAEMO_5
     if (!this->isActiveWindow()){
    QMaemo5InformationBox *box=new QMaemo5InformationBox();
-   QLabel *lbl=new QLabel("<center>Now playing :"+list.value(ui.listWidget->currentRow()).at(2)+" - "+list.value(ui.listWidget->currentRow()).at(1)+"</center>",box);
+   QLabel *lbl=new QLabel(tr("<center>Now playing : %1 - %2</center>").arg(list.value(ui.listWidget->currentRow()).at(2)).arg(list.value(ui.listWidget->currentRow()).at(1)),box);
   box->setWidget (lbl);
 box->setTimeout(3000);
 connect(box,SIGNAL(clicked()),this,SLOT(setFocus()));
@@ -958,18 +1023,6 @@ box->exec();}
     system(QString("fmtx_client -s \"%2\" -t \"%3\" >/dev/zero  2>/dev/zero").arg(ui.lineEdit->text()).arg(txt).toAscii());
     system("sudo /sbin/fm-boost");
 }
-
-
-    /*
-     iload - loading state variable
-     0- no load
-     1- just bios
-     2- bios+lyrics
-     3- bios-lyrics-images
-
-
-     */
-
     QString apath=QString(list.value(ui.listWidget->currentRow()).at(2)).toLower();
     apath.replace("/","");
     QString bpath=QString(apath+" - "+list.value(ui.listWidget->currentRow()).at(4)).toLower();
@@ -1046,6 +1099,12 @@ ui.textEdit_2->setText("");
         ui.pushButton_19->setEnabled(true);
     }else{
 
+    set_setting("last_played_l",ilist.value(ui.listWidget_2->currentRow()).at(0) );
+
+    if (moo->currentSource().url().toString().left(4)=="http"){
+
+    if (ui.checkBox_2->isChecked())
+    system("sudo /sbin/fm-boost");
 
         QMap<QString, QString> metaData = moo->metaData();
 
@@ -1064,7 +1123,7 @@ ui.textEdit_2->setText("");
   #ifdef Q_WS_MAEMO_5
        if (!this->isActiveWindow()){
        QMaemo5InformationBox *box=new QMaemo5InformationBox();
-       QLabel *lbl=new QLabel("Now playing :"+title+" - "+artist,box);
+       QLabel *lbl=new QLabel(tr("Now playing : %1 - %2").arg(title).arg(artist),box);
       box->setWidget (lbl);
     box->setTimeout(3000);
     connect(box,SIGNAL(clicked()),this,SLOT(setFocus()));
@@ -1075,12 +1134,128 @@ ui.textEdit_2->setText("");
        QPixmap *t=new QPixmap(":/icons/inet.png");
        ui.image->setPixmap(t->scaled(400,300,Qt::KeepAspectRatio,Qt::FastTransformation));
 
-ui.pushButton_19->setEnabled(false);
+       ui.pushButton_19->setEnabled(false);}
+
+}else{
+    //===========================================================================================================================================
+    emit this->track_change(moo->currentSource().fileName());
+
+    QMap<QString, QString> metaData = moo->metaData();
+
+    track_title = metaData.value("TITLE");
+    if (track_title == "")
+        track_title =metaInformationResolver->currentSource().fileName().split("/").last();
+
+    track_artist=metaData.value("ARTIST");
+    track_album=metaData.value("ALBUM");
+
+ui.label->setText(track_artist+" - "+track_title);
+this->setWindowTitle(track_artist+" - "+track_title);
+if (newstate==Phonon::PlayingState&&oldstate!=Phonon::PausedState){
+
+
+//scrobler->now(list.value(ui.listWidget->currentRow()),moo->totalTime());
+
+#ifdef Q_WS_MAEMO_5
+if (!this->isActiveWindow()){
+QMaemo5InformationBox *box=new QMaemo5InformationBox();
+QLabel *lbl=new QLabel(tr("<center>Now playing : %1 - %2</center>").arg(track_artist).arg(track_title),box);
+box->setWidget (lbl);
+box->setTimeout(3000);
+connect(box,SIGNAL(clicked()),this,SLOT(setFocus()));
+box->exec();}
+#endif
+}
+// fmtx
+if (ui.checkBox_2->isChecked()){
+QString txt=ui.lineEdit_2->text();
+txt.replace("%artist",track_artist);
+txt.replace("%track",track_title);
+system(QString("fmtx_client -s \"%2\" -t \"%3\" >/dev/zero  2>/dev/zero").arg(ui.lineEdit->text()).arg(txt).toAscii());
+system("sudo /sbin/fm-boost");
+}
+
+QString apath=QString(track_artist).toLower();
+apath.replace("/","");
+QString bpath=QString(apath+" - "+track_album).toLower();
+bpath.replace("/","");
+
+QString cpath=base_path+".covers/";
+
+QString dpath=QString(track_title).toLower();
+
+if (QFileInfo(cpath+bpath+".jpg").exists()){
+QPixmap *t=new QPixmap(cpath+bpath+".jpg");
+        ui.image->setPixmap(t->scaled(400,300,Qt::KeepAspectRatio,Qt::FastTransformation));
+}else{
+ if (QFileInfo(cpath+apath+".jpg").exists()){
+    QPixmap *t=new QPixmap(cpath+apath+".jpg");
+    ui.image->setPixmap(t->scaled(400,300,Qt::KeepAspectRatio,Qt::FastTransformation));
+
+}else{
+    ui.image->setPixmap(QPixmap());
+    if (iload>2){
+        dart();
     }
+}
+
+
+}
+ui.textEdit->setText("");
+ui.textEdit_2->setText("");
+
+QFile file(base_path+".bios/"+apath+".html");
+if (!file.exists()){
+if (iload>0){
+ QUrl url("http://team16.ru/grab.php?bio="+apath);
+
+ QNetworkAccessManager *manager = new QNetworkAccessManager(this);
+
+  connect(manager, SIGNAL(finished(QNetworkReply*)),
+          this, SLOT(replyFinished(QNetworkReply*)));
+
+
+  manager->get(QNetworkRequest(url));
+}
+}else{
+  if (!file.open(QIODevice::ReadOnly|QFile::Text))  return ;
+
+   QTextCodec *codec = QTextCodec::codecForName("UTF-8");
+
+ui.textEdit->setHtml( codec->toUnicode(file.readAll()));
+file.close();
+}
+
+QFile file2(base_path+".lyrics/"+apath+"-"+dpath+".html");
+if (!file2.exists()){
+  if (iload>1){
+   QUrl url("http://team16.ru/grab.php?band="+apath+"&lyrics="+dpath);
+
+   QNetworkAccessManager *manager = new QNetworkAccessManager(this);
+
+    connect(manager, SIGNAL(finished(QNetworkReply*)),
+            this, SLOT(replyFinished3(QNetworkReply*)));
+
+
+    manager->get(QNetworkRequest(url));
+}
+}else{
+    if (!file2.open(QIODevice::ReadOnly|QFile::Text))  return ;
+
+     QTextCodec *codec = QTextCodec::codecForName("UTF-8");
+
+ui.textEdit_2->setHtml( codec->toUnicode(file2.readAll()));
+file2.close();
+}
+
+ui.pushButton_19->setEnabled(true);
+    //===========================================================================================================================================
+}
+
+
 
     }
     }catch(int e){
-
     }
 }
 
@@ -1150,7 +1325,7 @@ if (list.value(ui.listWidget->currentRow()).at(4)!="Unknown")
 
 void MainWindow::dart2(){
     QMessageBox f;
-    f.setText("This process will start in background\n Just wait when inet request speed slow down to zero\nI will create an progress bar in nearest future");
+    f.setText(tr("This process will start in background\n Just wait when inet request speed slow down to zero\nI will create an progress bar in nearest future"));
     f.exec();
     for (int i=0;i<ui.listWidget->count();i++){
         ui.listWidget->setCurrentRow(i);
@@ -1193,11 +1368,17 @@ fl=reply->url().queryItems().at(0).second;
 
 
 
-    QString apath=QString(list.value(ui.listWidget->currentRow()).at(2)).toLower().replace("/","");
-    QString bpath=QString(apath+" - "+list.value(ui.listWidget->currentRow()).at(4)).toLower().replace("/","");
+    QMap<QString, QString> metaData = moo->metaData();
+
+    QString track_artist=metaData.value("ARTIST");
+    QString track_album=metaData.value("ALBUM");
+
+    QString apath=QString(track_artist.toLower().replace("/",""));
+    QString bpath=QString(apath+" - "+track_album.toLower().replace("/",""));
 
 
     QString cpath=base_path+".covers/";
+
     if (QFileInfo(cpath+bpath+".jpg").exists()){
 
         QPixmap *t=new QPixmap(cpath+bpath+".jpg");
@@ -1211,6 +1392,7 @@ fl=reply->url().queryItems().at(0).second;
 
          }
 }
+
 }
 
 void MainWindow::alistload(){
@@ -1237,30 +1419,23 @@ connect(lmast,SIGNAL(accepted()),this,SLOT(reload()));
 
     //
     tmenu->addSeparator();
-    tmenu->addAction("Light master",lmast,SLOT(exec()));
-
-
+    tmenu->addAction(tr("Master"),lmast,SLOT(exec()));
 
     tmenu->exec(QCursor::pos());
-
-
-
-
-
 }
 
 void MainWindow::pl_fn_click(){
 QMenu fh;
-QMenu add("Add");
-QMenu mv("Moving");
+QMenu add(tr("Add"));
+QMenu mv(tr("Moving"));
 fh.addMenu(&add);
 fh.addMenu(&mv);
 //add.addAction("Track",this,SLOT(pl_fn_add_track()));
-add.addAction("Directory",this,SLOT(pl_fn_add_dir()));
-fh.addAction("Clear",this,SLOT(clear()));
-mv.addAction("To begin",ui.listWidget,SLOT(scrollToTop()));
-mv.addAction("To end",ui.listWidget,SLOT(scrollToBottom()));
-mv.addAction("Find",this,SLOT(find()));
+add.addAction(tr("Directory"),this,SLOT(pl_fn_add_dir()));
+fh.addAction(tr("Clear"),this,SLOT(clear()));
+mv.addAction(tr("To begin"),ui.listWidget,SLOT(scrollToTop()));
+mv.addAction(tr("To end"),ui.listWidget,SLOT(scrollToBottom()));
+mv.addAction(tr("Find"),this,SLOT(find()));
  fh.exec(QCursor::pos());
 }
 
@@ -1286,12 +1461,21 @@ void MainWindow::find(){
 }
 
 
+void MainWindow::set_list(){
+    QString lst=QFileDialog::getOpenFileName(this,tr("Open *.m3u"),"/home/user/MyDocs","*.m3u (*.m3u)",new QString("*.m3u (*.m3u)"));
+    if (!lst.isEmpty())set_setting("list_path",lst);
+    load_inet();
+
+}
+
 void MainWindow::i_fn_click(){
 QMenu fh;
 
-fh.addAction("To begin",ui.listWidget_2,SLOT(scrollToTop()));
-fh.addAction("To end",ui.listWidget_2,SLOT(scrollToBottom()));
-fh.addAction("Find",this,SLOT(findi()));
+fh.addAction(tr("Load another *.m3u"),this,SLOT(set_list()));
+
+fh.addAction(tr("To begin"),ui.listWidget_2,SLOT(scrollToTop()));
+fh.addAction(tr("To end"),ui.listWidget_2,SLOT(scrollToBottom()));
+fh.addAction(tr("Find"),this,SLOT(findi()));
 fh.exec(QCursor::pos());
 }
 
@@ -1322,12 +1506,11 @@ void MainWindow::pl_fn_add_dir(){
 
 
     QString d;
-    QString f=QFileDialog::getExistingDirectory(this,"Tplayer",base_path+"MyDocs/.sounds",QFileDialog::ReadOnly);
+    QString f=QFileDialog::getExistingDirectory(this,"TPlayer","/home/user/MyDocs/.sounds",QFileDialog::ReadOnly);
    QApplication::processEvents();
 
     if (!f.isEmpty())
     {
-
         ld->setModal(true);
         ld->open();
         loading->setMaximum(100);
@@ -1335,8 +1518,6 @@ void MainWindow::pl_fn_add_dir(){
          loading->show();
 QApplication::processEvents();
 
-
-
 QDir fg(f);
 fg.setFilter(QDir::AllDirs|QDir::Files);
 fg.setNameFilters(namefilter);
@@ -1345,7 +1526,6 @@ fg.setNameFilters(namefilter);
         QDirIterator it(fg, QDirIterator::Subdirectories|QDirIterator::FollowSymlinks);
         while (it.hasNext()) {
          d=it.next();
-
          QFileInfo hj(d);
          if (hj.isFile()){
 l++;
@@ -1353,16 +1533,12 @@ ld->setWindowTitle(d);
                   getMeta(d);
                   QApplication::processEvents();
               }
-
     }
     }
 
     loading->setMaximum(l);
     loading->setValue(0);
 
-
-
-
     if (l>0){
     metaInformationResolver->setCurrentSource(queue.last());
 
@@ -1381,9 +1557,8 @@ void MainWindow::ch(){
 }
 
 void MainWindow::drawlist(){
-  //  ld->accept();
     ui.listWidget->clear();
-list.clear();
+    list.clear();
 
     QSqlQuery query(currentQuery,db);
     int id=0;
